# vasp.parameters module

```{eval-rst}
.. automodule:: vasp.parameters
   :members:
   :undoc-members:
   :show-inheritance:
```

## Preset Functions

```{eval-rst}
.. autofunction:: vasp.parameters.get_preset
.. autofunction:: vasp.parameters.get_vdw_params
.. autofunction:: vasp.parameters.get_ldau_params
.. autofunction:: vasp.parameters.get_hybrid_params
.. autofunction:: vasp.parameters.get_soc_params
```

## Data Classes

```{eval-rst}
.. autoclass:: vasp.parameters.HubbardU
   :members:
   :undoc-members:
```
